@@ -13,8 +13,14 @@ _LOGGER = logging.getLogger(__name__)
 class OpenGarage:
     """Class to communicate with the Open Garage api."""
 
+    # pylint: disable=too-many-arguments
     def __init__(
-        self, devip, devkey, verify_ssl=False, websession=None, timeout=DEFAULT_TIMEOUT,
+        self,
+        devip,
+        devkey,
+        verify_ssl=False,
+        websession=None,
+        timeout=DEFAULT_TIMEOUT,
     ):
         """Initialize the Open Garage connection."""
         if websession is None:
@@ -31,6 +37,11 @@ class OpenGarage:
         self._devkey = devkey
         self._verify_ssl = verify_ssl
 
+    @property
+    def device_url(self):
+        """Device url."""
+        return self._devip
+
     async def close_connection(self):
         """Close the connection."""
         await self.websession.close()
@@ -45,14 +56,14 @@ class OpenGarage:
         if result is None:
             return None
         return result.get("result")
-    
+
     async def reboot(self):
         """Reboot device."""
         result = await self._execute(f"cc?dkey={self._devkey}&reboot=1")
         if result is None:
             return None
         return result.get("result")
-    
+
     async def ap_mode(self):
         """Reset device in AP mode (to reconfigure WiFi settings)."""
         result = await self._execute(f"cc?dkey={self._devkey}&apmode=1")
